==> gazie7.30.zip: gazie/modules/magazz/menu.spanish.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/

/*
 -- TRANSLATED BY : Dante Becerra Lagos (softenglish@gmail.com)
*/

$transl['magazz'] = array('name' => "Bodega",
                          'title' => "Administracion de Bodega",
                          'm2' => array( 1 =>array("Administrar Itemes ","Itemes"),
                                         2 =>array("Administrar Grupo de Items","Grupo de Items"),
                                         3 =>array("Administrar movimientos de Bodega","Movimientos"),
                                         4 =>array("Causales Bodega","Causales"),
                                         5 =>array("Itemes elegidos para lista de precios","Lista de Precios"),
                                         6 =>array("Actualizar precios de articulos","Actualizar Precios"),
                                         7 =>array("Seleccion de Articulos para la creacion de folleto","Catalogo"),
                                         8 =>array("Estadisticas de existencias","Estadisticas"),
                                         9 =>array("Statistic groups manage","Statistic groups")
                                         ),
                          'm3' => array( 1 =>array("Insertar nuevo item","Nuevo item"),
                                         2 =>array("Insertar nuevo grupo de items","Nuevo grupo de itemes"),
                                         3 =>array("Insertar nuevo movimiento de bodega","Nuevo movimiento de bodega"),
                                         4 =>array("Imprimir reporte de itemes","Imprimir reporte de itemes"),
                                         5 =>array("Imprimir diario de almacen","Imprimir diario de almacen"),
                                         6 =>array("Crear movimientos de bodega desde documentos","Crear movimientos de bodega"),
                                         7 =>array("Insertar nueva causal de bodega","Nueva causal de bodega"),
                                         8 =>array("Reevaluacion de articulos existentes","Reevaluacion existencias"),
                                         9 =>array("Inventario de Existencias","Inventario de Existencias"),
                                         10 =>array("Documentos y / o certificación de productos","Documentos y/o certificación"),
                                         11 =>array("Cambio de la tasa del IVA de los Articulos","Cambio IVA articulos"),
                                         12 =>array("Insert new statistic group","New statistic group"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino")
                                      )
                          );
?>

==> gazie8.00.zip: gazie/modules/magazz/menu.spanish.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/

/*
 -- TRANSLATED BY : Dante Becerra Lagos (softenglish@gmail.com)
*/

$transl['magazz'] = array('name' => "Bodega",
                          'title' => "Administracion de Bodega",
                          'm2' => array( 1 =>array("Administrar Itemes ","Itemes"),
                                         2 =>array("Administrar Grupo de Items","Grupo de Items"),
                                         3 =>array("Administrar movimientos de Bodega","Movimientos"),
                                         4 =>array("Causales Bodega","Causales"),
                                         5 =>array("Itemes elegidos para lista de precios","Lista de Precios"),
                                         6 =>array("Actualizar precios de articulos","Actualizar Precios"),
                                         7 =>array("Seleccion de Articulos para la creacion de folleto","Catalogo"),
                                         8 =>array("Estadisticas de existencias","Estadisticas"),
                                         9 =>array("Statistic groups manage","Statistic groups"),
                                         10 =>array("Warehouse manage","Warehouse")
                                         ),
                          'm3' => array( 1 =>array("Insertar nuevo item","Nuevo item"),
                                         2 =>array("Insertar nuevo grupo de items","Nuevo grupo de itemes"),
                                         3 =>array("Insertar nuevo movimiento de bodega","Nuevo movimiento de bodega"),
                                         4 =>array("Imprimir reporte de itemes","Imprimir reporte de itemes"),
                                         5 =>array("Imprimir diario de almacen","Imprimir diario de almacen"),
                                         6 =>array("Crear movimientos de bodega desde documentos","Crear movimientos de bodega"),
                                         7 =>array("Insertar nueva causal de bodega","Nueva causal de bodega"),
                                         8 =>array("Reevaluacion de articulos existentes","Reevaluacion existencias"),
                                         9 =>array("Inventario de Existencias","Inventario de Existencias"),
                                         10 =>array("Documentos y / o certificación de productos","Documentos y/o certificación"),
                                         11 =>array("Cambio de la tasa del IVA de los Articulos","Cambio IVA articulos"),
                                         12 =>array("Insert new statistic group","New statistic group"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino"),
                                         14 =>array("Insertar nuevo grupo","Insertar nuevo grupo"),
                                         14 =>array("Insert new warehouse","Insert new warehouse")
                                      )
                          );
?>
